==> com.liferay.object.service-1.0.61-sources-commercial.jar: com/liferay/object/internal/search/spi/model/index/contributor/ObjectValidationRuleModelDocumentContributor.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.search.spi.model.index.contributor;

import com.liferay.object.model.ObjectValidationRule;
import com.liferay.portal.kernel.search.Document;
import com.liferay.portal.kernel.search.Field;
import com.liferay.portal.kernel.service.ClassNameLocalService;
import com.liferay.portal.kernel.util.LocalizationUtil;
import com.liferay.portal.search.spi.model.index.contributor.ModelDocumentContributor;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(
	immediate = true,
	property = "indexer.class.name=com.liferay.object.model.ObjectValidationRule",
	service = ModelDocumentContributor.class
)
public class ObjectValidationRuleModelDocumentContributor
	implements ModelDocumentContributor<ObjectValidationRule> {

	@Override
	public void contribute(
		Document document, ObjectValidationRule objectValidationRule) {

		document.addLocalizedText(
			Field.NAME,
			LocalizationUtil.populateLocalizationMap(
				objectValidationRule.getNameMap(),
				objectValidationRule.getDefaultLanguageId(), 0));
		document.addKeyword(
			"objectDefinitionId", objectValidationRule.getObjectDefinitionId());
		document.remove(Field.USER_NAME);
	}

	@Reference
	protected ClassNameLocalService classNameLocalService;

}

==> com.liferay.object.service-1.0.122-sources-commercial.jar: com/liferay/object/internal/search/spi/model/index/contributor/ObjectValidationRuleModelDocumentContributor.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.object.internal.search.spi.model.index.contributor;

import com.liferay.object.model.ObjectValidationRule;
import com.liferay.portal.kernel.search.Document;
import com.liferay.portal.kernel.search.Field;
import com.liferay.portal.kernel.service.ClassNameLocalService;
import com.liferay.portal.kernel.util.Localization;
import com.liferay.portal.search.spi.model.index.contributor.ModelDocumentContributor;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Marcela Cunha
 */
@Component(
	property = "indexer.class.name=com.liferay.object.model.ObjectValidationRule",
	service = ModelDocumentContributor.class
)
public class ObjectValidationRuleModelDocumentContributor
	implements ModelDocumentContributor<ObjectValidationRule> {

	@Override
	public void contribute(
		Document document, ObjectValidationRule objectValidationRule) {

		document.addLocalizedText(
			Field.NAME,
			_localization.populateLocalizationMap(
				objectValidationRule.getNameMap(),
				objectValidationRule.getDefaultLanguageId(), 0));
		document.addKeyword(
			"objectDefinitionId", objectValidationRule.getObjectDefinitionId());
		document.remove(Field.USER_NAME);
	}

	@Reference
	protected ClassNameLocalService classNameLocalService;

	@Reference
	private Localization _localization;

}
